#
# spec file for package qutebrowser
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           qutebrowser
Version:        0.8.1
Release:        1.2
Summary:        Keyboard-driven vim-like browser on Qt5
License:        GPL-3.0+
Group:          Productivity/Networking/Web/Browsers
Url:            https://qutebrowser.org/
Source:         https://github.com/The-Compiler/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/The-Compiler/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python3-Jinja2
BuildRequires:  python3-MarkupSafe
BuildRequires:  python3-PyYAML
BuildRequires:  python3-Pygments
BuildRequires:  python3-devel >= 3.4
BuildRequires:  python3-pyPEG2
BuildRequires:  python3-qt5 >= 5.2
BuildRequires:  update-desktop-files
Requires:       python3-Jinja2
Requires:       python3-MarkupSafe
Requires:       python3-PyYAML
Requires:       python3-Pygments
Requires:       python3-pyPEG2
Requires:       python3-qt5 >= 5.2
Recommends:     python3-cssutils
BuildArch:      noarch

%description
qutebrowser is a keyboard-focused browser with a minimal GUI.
It's based on Python, PyQt5 and QtWebKit and is free software.

%prep
%setup -q

%build
python3 setup.py build

%install
python3 setup.py install \
  --root=%{buildroot} --prefix=%{_prefix}

install -Dm 0644 %{name}.desktop \
  %{buildroot}%{_datadir}/applications/%{name}.desktop

for size in 16 24 32 48 64 128 256; do
    install -Dm 0644 "icons/%{name}-${size}x${size}.png" \
      "%{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/apps/%{name}.png"
done
install -Dm 0644 icons/%{name}.svg \
  %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%fdupes %{buildroot}%{python3_sitelib}/

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc CHANGELOG.asciidoc COPYING README.asciidoc
%{_bindir}/%{name}
%{python3_sitelib}/%{name}/
%{python3_sitelib}/%{name}-*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*

%changelog
* Sat Jul 30 2016 sor.alexei@meowr.ru
- Update to version 0.8.1 (changes since 0.7.0):
  * Add new ":repeat-command" command (mapped to ".") to repeat the
    last command.
    Note that two former default bundings conflict with that
    binding, unbinding them via ":unbind .i" and ":unbind .o" is
    recommended.
  * Add new "qute:bookmarks" page which displays all bookmarks and
    quickmarks.
  * Add new ":prompt-open-download" (bound to Ctrl-X) which can be
    used to open a download directly when getting the filename
    prompt.
  * Add new "{host}" replacement for tab- and window titles which
    evaluates to the current host.
  * Add new default binding ";t" for ":hint input".
  * Add new variables "$QUTE_CONFIG_DIR", "$QUTE_DATA_DIR" and
    "$QUTE_DOWNLOAD_DIR" available for userscripts.
  * Add new option "ui" -> "status-position" to configure the
    position of the status bar (top/bottom).
  * Add new "--pdf <filename>" argument for ":print" WHICH can be
    used to generate a PDF without a dialog.
  * ":scroll-perc" now prefers a count over the argument given to
    it, which means "gg" can be used with a count.
  * Aliases can now use ";;" to have an alias which executed
    multiple commands.
  * ":edit-url" now does nothing if the URL isn't changed in the
    spawned editor.
  * ":bookmark-add" can now be passed a URL and title to add that
    as a bookmark rather than the current page.
  * New "taskadd" userscript to add a taskwarrior task annotated
    with the current URL.
  * ":bookmark-del" and ":quickmark-del" now delete the current
    page's URL if none is given.
  * Fix compatibility with PyQt 5.7.
  * Fix some configuration values being lost when a config option
    gets removed from qutebrowser's code.
  * Fix a crash when downloading with a full drive.
  * Fix using ":jump-mark" (e.g. '') when the current URL is
    invalid doesn't crash anymore.
  * Fix a crash when pressing enter without a command.
  * Remove the ability to display status messages from webpages, as
    well as the related "ui" -> "display-statusbar-messages"
    setting.
  * Remove the "general" -> "wrap-search" setting as searches now
    always wrap.
    According to a quick straw poll and prior crash logs, almost
    nobody is using "wrap-search = false", and turning off wrapping
    is not possible with QtWebEngine.
  * Remove ":edit-url" now doesn't accept a count anymore as its
    behaviour was confusing and it doesn't make much sense to add a
    count.
* Sat Jun 11 2016 sor.alexei@meowr.ru
- Update to version 0.7.0:
  * Add new ":edit-url" command to edit the URL in an external
    editor.
  * Add new "network -> custom-headers" setting to send custom
    headers with every request.
  * Add new "{url:pretty}" commandline replacement which gets
    replaced by the decoded URL.
  * Add new marks to remember a scroll position.
  * Add new ":jump-mark" command to jump to a mark, bound to "'".
  * Add new ":set-mark" command to set a mark, bound to ```
    (backtick).
  * Now the "'" mark gets set when moving away (hinting link with
    anchor, searching, etc.) so you can move back with "''".
  * Add new "--force-color" argument to force coloured logging even
    if stdout is not a terminal.
  * Add new ":messages" command to show error messages.
  * Add new pop-up showing possible keybinding when the first key
    of a keychain is pressed. This can be turned off using
    ":set ui keyhint-blacklist *".
  * Add new "hints -> auto-follow-timeout" setting to ignore
    keypresses after following a hint when filtering in number mode.
  * Add new ":history-clear "command to clear the entire history
  * Add new "hints -> find-implementation" to select which
    implementation (JS/Python) should be used to find hints on a
    page. The javascript implementation is better, but slower.
  * Change (slightly update) logo.
  * ":tab-focus" can now take a negative index to focus the nth tab
    counted from the right.
  * ":yank" can now yank the pretty/decoded URL by adding "--pretty".
  * ":navigate" now clears the URL fragment.
  * ":completion-item-del" (Ctrl-D) can now be used in ":buffer"
    completion to close a tab.
  * Counts can now be used with special keybindings (e.g. with
    modifiers).
  * Various SSL ciphers are now disabled by default. With recent
    Qt/OpenSSL versions those already all are disabled, but with
    older versions they might not be.
  * Show favicons as window icon with tabs-are-windows set.
  * ":bind <key>" without a command now shows the existing binding.
  * The optional colorlog dependency got removed, as qutebrowser
    now displays coloured logs without it.
  * URLs are now shown decoded when hovering.
  * Keybindings are now shown in the command completion.
  * Improved behaviour when pasting multiple lines.
  * Rapid hints can now also be used for the normal hint target,
    which can be useful with javascript click handlers or
    checkboxes which don’t actually open a new page.
  * ":zoom-in" or ":zoom-out" (+/-) with a too large count now
    zooms to the smallest/largest zoom instead of doing nothing.
  * The commandline now accepts partially typed commands if they’re
    unique.
  * Number hints are now kept filtered after following a hint in
    rapid mode.
  * Number hints are now renumbered after filtering.
  * Number hints can now be filtered with multiple space-separated
    search terms.
  * "hints -> scatter" is now ignored for number hints.
  * Better history implementation which also stores titles. As a
    consequence, URLs which redirect to another URL are now added to
    the history too, marked with an -r suffix to the timestamp field.
  * Fix using ":hint links spawn" with flags – you can now use
    things like the -v argument for ":spawn" or pass flags to the
    spawned commands.
  * Various fixes for hinting corner-cases where following a link
    didn’t work or the hint was drawn at the wrong position.
  * Fix crash when downloading from an URL with SSL errors.
  * Close file handles correctly when a download failed.
  * Fix crash when using ";Y" (":hint links yank-primary") on a
    system without primary selection.
  * Don’t display quit confirmation with finished downloads.
  * Fix updating the tab index in the statusbar when opening a
    background tab.
  * Fix a crash when entering `:-- ` in the commandline.
  * Fix ":debug-console" with PyQt 5.6.
  * Fix qutebrowser not starting when sys.stderr is None.
  * Fix a crash when cancelling a download which belongs to a MHTML
    download.
  * Fix rebinding of keybindings being case-sensitive.
  * Fix for tab indicators getting lost when moving tabs.
  * Fix handling of backspace in number hinting mode.
  * Fix FileNotFoundError when starting in some cases on old Qt
    versions.
  * Fix sharing of cookies between tabs when "private-browsing" is
    enabled.
  * Toggling values with ":set" now uses lower-case values.
  * Hints now work with (non-standard) links with spaces around the
    URL.
  * Strip off trailing spaces for history entries with no title.
* Sat May  7 2016 sor.alexei@meowr.ru
- Update to version 0.6.2:
  * Fix crash when using :tab-{prev,next,focus} right after closing
    the last tab with last-close set to close.
  * Fix crash when doing :undo in a new instance with
    tabs -> last-close set to default-page.
  * Fix crash when starting with --cachedir="".
  * Fix crash in some circumstances when using dictionary hints.
  * Fix various crashes related to PyQt 5.6.
* Thu Apr 21 2016 sor.alexei@meowr.ru
- Initial Package.
